.. _exceptions_module:

:mod:`pyramid.exceptions`
----------------------------

.. automodule:: pyramid.exceptions

  .. autoexception:: BadCSRFOrigin

  .. autoexception:: BadCSRFToken

  .. autoexception:: PredicateMismatch

  .. autoexception:: Forbidden

  .. autoexception:: NotFound

  .. autoexception:: ConfigurationError

  .. autoexception:: URLDecodeError
